@@ -1,18 +1,46 @@
 from pygl_nf import GL
 from colorama import Fore as FO
 import sys
+import time
 import os
 
+initing = False
+def Init():
+    global initing
+
+    for i in range(5): 
+        os.system('cls')
+        print(FO.CYAN+'Prefabs Initing'+FO.RESET,end='')
+        print(FO.CYAN+'.'*(i+1)+FO.RESET)
+        time.sleep(0.1)
+    os.system('cls')
+
+    if os.path.exists('Prefabs'):
+        initing = True
+        print(FO.GREEN+'''[ Success ]'''+FO.RESET)
+        print(FO.GREEN+'Prefabs Init!'+FO.RESET)
+    else:
+        print(FO.RED+'''[ Error ]'''+FO.RESET)
+        print(FO.RED+'Prefabs Not Init!'+FO.RESET)
+        print(FO.YELLOW+'Prefab file not found'+FO.RESET)
+    
+    
+    
 
 
 class Sound(object):
-    def __init__(self,Prefabs_directory=None):
-        self.Prefabs_directory = Prefabs_directory
+    def __init__(self):
+        global initing
+        if initing==False:
+            print(FO.RED+'''[ Error ]'''+FO.RESET)
+            print(FO.RED+'Prefabs Not Init!'+FO.RESET)
+            sys.exit()
+            
     class Jamps(object):
         def __init__(self):
-            self.jamp1 = self.Prefabs_directory+'Prefabs\Sounds\Jamps\Jump1.wav'
-            self.jamp2 = self.Prefabs_directory+'Prefabs\Sounds\Jamps\Jump2.wav'
-            self.jamp3 = self.Prefabs_directory+'Prefabs\Sounds\Jamps\Jump3.wav'
+            self.jamp1 = 'Prefabs\Sounds\Jamps\Jump1.wav'
+            self.jamp2 = 'Prefabs\Sounds\Jamps\Jump2.wav'
+            self.jamp3 = 'Prefabs\Sounds\Jamps\Jump3.wav'
             self.jamp4 = 'Prefabs\Sounds\Jamps\Jump4.wav'
             self.jamp5 = 'Prefabs\Sounds\Jamps\Jump5.wav'
             self.jamp6 = 'Prefabs\Sounds\Jamps\Jump6.wav'
@@ -21,18 +49,8 @@ class Sound(object):
             self.jamp9 = 'Prefabs\Sounds\Jamps\Jump9.wav'
             self.jamp10 = 'Prefabs\Sounds\Jamps\Jump10.wav'
 
-            jamp1 = self.jamp1
-            jamp2 = self.jamp2
-            jamp3 = self.jamp3
-            jamp4 = self.jamp4
-            jamp5 = self.jamp5
-            jamp6 = self.jamp6
-            jamp7 = self.jamp7
-            jamp8 = self.jamp8
-            jamp9 = self.jamp9
-            jamp10 = self.jamp10
 
-            self._Jamp_Sounds = [jamp1,jamp2,jamp3,jamp4,jamp5,jamp6,jamp7,jamp8,jamp9,jamp10]
+            self._Jamp_Sounds = [self.jamp1,self.jamp2,self.jamp3,self.jamp4,self.jamp5,self.jamp6,self.jamp7,self.jamp8,self.jamp9,self.jamp10]
 
         def GET_SOUND_FOR_NAME(self,Sound_file):
             sound = GL.Sound_mixer_(Sound_file)
@@ -58,18 +76,8 @@ class Sound(object):
             self.pickup9 = 'Prefabs\Sounds\Pickuping\Pickup_Coin9.wav'
             self.pickup10 = 'Prefabs\Sounds\Pickuping\Pickup_Coin10.wav'
 
-            pickup1 = self.pickup1
-            pickup2 = self.pickup2
-            pickup3 = self.pickup3
-            pickup4 = self.pickup4
-            pickup5 = self.pickup5
-            pickup6 = self.pickup6
-            pickup7 = self.pickup7
-            pickup8 = self.pickup8
-            pickup9 = self.pickup9
-            pickup10 = self.pickup10
 
-            self._Pickup_Sounds = [pickup1,pickup2,pickup3,pickup4,pickup5,pickup6,pickup7,pickup8,pickup9,pickup10]
+            self._Pickup_Sounds = [self.pickup1,self.pickup2,self.pickup3,self.pickup4,self.pickup5,self.pickup6,self.pickup7,self.pickup8,self.pickup9,self.pickup10]
 
         def GET_SOUND_FOR_NAME(self,Sound_file):
             sound = GL.Sound_mixer_(Sound_file)
